# cxxrdp
C++ implementation of RDP

## Install via pip
Run following command to install cxxrdp on your computer

    pip install cxxrdp

## How to use?

.. code:: python

    from cxxrdp import rdp

    rdp([[0, 5], [5, 5], [10, 5], [15, 5]])

.. code:: python

    [[0, 5], [15, 5]]
